# Key

Symbols are used in headings to denote what platforms and symbol types a command supports.

- Telegram Only :fontawesome-brands-telegram-plane:
- Discord Only :fontawesome-brands-discord:
- Bot Commands :robot:
- Cryptocurrency Support :material-currency-btc:
- Stock Market Support :bank:
- OTC Support :dollar:

# Symbol Detection :material-currency-btc: :bank: :dollar:

The Simple Stock Bot looks at every message it can see and tries to detect stock and cryptocurrency symbols. Stock market tickers are denoted with a single `$` and cryptocurrency coins are denoted with a double `$$`. So getting the price of Tesla is as simple as `$tsla` and Bitcoin `$$btc`. These symbols can be in any part of a message and there can be multiple of them aswell.

<div class="phone">
    <div class="messages-wrapper">
        <div class="message to">
            I wonder how $tsla is affecting the price of $$btc
        </div>
        <div class="message from">
        The current stock price of Tesla Inc is $866.57, the stock is currently up 1.68%
        </div>
        <div class="message from">
        The current price of Bitcoin is $34,815, the coin is currently down -0.151% for today
        </div>
    </div>
</div>

# `/donate [Amount in USD]` :fontawesome-brands-telegram-plane:

The donate command is used to send money to the bot to help keep it free. The premium stock market data and server rentals add up so any amount helps. See the [Donate](#donate) page for more information.

<div class="phone">
    <div class="messages-wrapper">
        <div class="message to">
            /donate
        </div>
        <div class="message from">
            The current stock price of Tesla Inc is $664.315, the stock is
            currently down -0.99%
        </div>
    </div>
</div>

# `/status` :fontawesome-brands-telegram-plane: :fontawesome-brands-discord:

This command is to get diagnostic information about the bot and the services it is dependant on in order to operate. Any issues should be reported to me. [Contact](#contact)

<div class="phone">
    <div class="messages-wrapper">
        <div class="message to">
            /status
        </div>
        <div class="message from">
Bot Status:
        It took 0.783369 seconds for the bot to get your message.

        Stock Market Data:
        IEX Cloud is currently not reporting any issues with its API.

        Cryptocurrency Data:
        CoinGecko API responded that it was OK in 0.160962 Seconds.
        </div>
    </div>

</div>

# `/dividend [symbol]` :bank:

This command gives the rate and date of the dividend for a stock symbol.

<div class="phone">
    <div class="messages-wrapper">
        <div class="message to">
            /dividend $psec
        </div>
        <div class="message from">
The next dividend for $PSEC: Prospect Capital Corp is on Thursday, August 4 which is in 44 days. The dividend is for $0.06 per share.
</br></br>
The dividend was declared on Monday, May 1 and the ex-dividend date is Tuesday, July 2

        </div>
    </div>

</div>

# `/intra [symbol]` :bank: :material-currency-btc:

This command makes a chart of a stocks movement since the last market open, or the last 24 hours for cryptocurrency.

<div class="phone">
    <div class="messages-wrapper">
        <div class="message to">
            /intra $astr
        </div>
        <div class="message from">
          <img src="/img/TgIntraChat.jpg" alt="Tesla Motors Chart" />
          <p>Intraday chart for $ASTR from 06 Jul at 09:30 to 06 Jul at 15:59</p>
          <p>The current stock price of Astra Space Inc - Class A is $12.47, the stock is currently down -19.39%</p>
        </div>

    </div>

</div>

# `/chart [symbol]` :bank: :material-currency-btc:

This command makes a chart of the last 1 month of trading data up until the day before. For example running it on May 5th creates a chart from April 5th to May 4th.

<div class="phone">
    <div class="messages-wrapper">
        <div class="message to">
            /intra $astr
        </div>
        <div class="message from">
          <img src="/img/TgChartChat.jpg" alt="Tesla Motors Chart" />
          <p>1 Month chart for Ethereum from 07, Jun 2021 to 07, Jul 2021</p>
          <p>The current price of Ethereum is $2,389.62, the coin is currently up 2.485% for today</p>
        </div>

    </div>

</div>

# `/news [symbol]` :bank:

Gets the most recent, non paywalled, english news for a stock.

<div class="phone">
    <div class="messages-wrapper">
        <div class="message to">
            /news
        </div>
        <pre class="message from">
News for TSLA:
Top Tech News: Elon Musk admits self-driving is harder than he thought as Tesla owners troll him over missed deadlines
Bitcoin Ethereum News: DOGE Price Analysis $0.231 | Cryptopolitan
Tesla North: Bugatti to Merge with EV Hypercar Startup Rimac
Tesla North: China-Made Tesla Model 3 Battery Drain Test After 14 Days of Sleep
Tesmanian: Brandenburg Minister Supports Bureaucratic Reform & Hopes Tesla Giga Berlin Production Starts this Year
        </pre>
    </div>
</div>

# /info :fontawesome-brands-telegram-plane: :fontawesome-brands-discord: :bank: :material-currency-btc:

Gets a description of a company. Aimed to inform you on what a ticker is if you have no prior knowledge of it.

<div class="phone">
    <div class="messages-wrapper">
        <div class="message to">
            /info $spce
        </div>
        <div class="message from">
Virgin Galactic Holdings, Inc. is a vertically integrated aerospace and space travel company, pioneering human spaceflight for private individuals and researchers, as well as a manufacturer of advanced air and space vehicles. It is developing a spaceflight system designed to offer customers a unique and transformative experience.
        </div>
    </div>
</div>

# `/stat [symbol]` :fontawesome-brands-telegram-plane: :fontawesome-brands-discord:

Gets key market data of the symbol passed in.

<div class="phone">
    <div class="messages-wrapper">
        <div class="message to">
            /stat $$ada
        </div>
        <pre class="message from">
Cardano Statistics:
    Market Cap: $0.0
    Market Cap Ranking: None
    CoinGecko Scores:
        Overall: 8.928
        Development: 0.0
        Community: 12.066
        Public Interest: 0.285
        </pre>
        <div class="message to">
            /stat $$ada
        </div>
        <pre class="message from">
Company Name: Prospect Capital Corp
Market Cap: $3,280,433,315
52 Week (high-low): 9.19 - 4.21
Number of Employees: 0
Next Earnings Date: 2021-08-26
Price to Earnings: 0.000
Beta: 0.404
        </pre>
    </div>
</div>

# `/trending` :fontawesome-brands-telegram-plane:

Gets the latest trending stocks and their change in price

<div class="phone">
    <div class="messages-wrapper">
        <div class="message to">
            /trending
        </div>
        <div class="message from">
Trending Stocks:
```
$SPCE: Virgin Galactic Holdings Inc - Class A, 0.04%
$MRIN: Marin Software Inc, 0.35%
$AMC: AMC Entertainment Holdings Inc - Class A, -0.04%
$ITRM: Iterum Therapeutics Plc, -0.38%
$AAPL: Apple Inc, 0.02%
$WISH: ContextLogic Inc - Class A, -0.05%
$AHT: Ashford Hospitality Trust Inc, -0.08%
$AMD: Advanced Micro Devices Inc., 0.01%
$CTXR: Citius Pharmaceuticals Inc, -0.17%
$F: Ford Motor Co., 0.00%
```

Trending Crypto:

```
$$BOND: BarnBridge, -5.29%
$$SHIB: Shiba Inu, -3.76%
$$SNX: Synthetix Network Token, 21.45%
$$COMP: Compound, 11.95%
$$MATIC: Polygon, -4.11%
$$AXS: Axie Infinity, -9.02%
$$MLN: Enzyme, 32.85%
```

        </div>
    </div>

</div>

# /help :robot:

Just a simple command to get help in app. Returns a more summarized version of this page.

<div class="phone">
    <div class="messages-wrapper">
        <div class="message to">
            /help
        </div>
        <div class="message from">
            The current stock price of Tesla Inc is $664.315, the stock is
            currently down -0.99%
        </div>
    </div>
</div>

# Inline Features :fontawesome-brands-telegram-plane: :material-currency-btc: :bank: :dollar:

You can type @SimpleStockBot `[search]` in any chat or direct message to search for the stock bots
full list of stock symbols and return the price of the ticker. Then once you select the ticker
want the bot will send a message as you in that chat with the latest stock price.
The bot also looks at every message in any chat it is in for stock symbols.Symbols start with a
`$` followed by the stock symbol. For example:$tsla would return price information for Tesla Motors.
